@@ -5,8 +5,74 @@ __all__ = [
     "make_tex_document_1",
     "build_bbox",
 ]
+'''
+Function used for Batch processing of the confocal images
+
+Inputs 
+Confocal images as .plu files (binary standard of Sensofar company)
+
+Input files organization 
+For several images 'wafer #-&' per wafer 'wafer #' per cut 'cut ###'
+
+the files organization is as follows:
+
+root / cut ### / wafer # / save_plu / wafer #-&.plu
+where:
+
+    - & stands for a, b, c, d, e 
+    - \# stands for a digit
+    - total number of files is open for each 'wafer #'
+    - total number of cuts ### defined by length of list cuts
+
+Outputs
+5 files per image 'wafer #-&' 
+    - EXCEL file 'wafer#-&.xlsx' containing the morphological information of the features
+    - JPEG file of the corrected raw image with indication of the corrected pixels
+    - JPEG file 'wafer#-&-im-rebuild.jpg' of the features represented in colored circular dots of equivalent area as the real features
+with color scale relative to the features depth
+    - JPEG file 'wafer#-&-im-bbox.jpg' of the features size histogram
+    - JPEG file 'wafer#-&-im-hist.jpg' of box plot of the features size
+
+A $\LaTeX$ file 'cut_report ###.tex' as a report gathering the 4 JPEG files and a graph per cut integrating all the corresponding box plots 
+
+output files location 
+'root / cut ### / wafer # / results /' for 'wafer#-&.xlsx' and the JPEG files 
+'root / cut ### /' for cut_report ###.tex
+
+where:
+    - & stands for a, b, c, d, e 
+    - \# stands for a digit, 
+
+'''
+
 
 def image_processing_1(param, analyse_morpho=True):
+    '''
+    Process an image by:
+        - reading a .plu image
+        - substituing non measured values by interpolated ones
+        - levelling the image using a morphological filter (top hat)
+        - binarizing the image using a threshold
+        - doing an image morphological analysis
+    Arguments:
+        param (dict) : param["repertoire"] name of the directory
+                       param["file"] name of the file to process
+                       param["dir_results"] name of the directory where the morphological resuts are stored
+                       param['Top_hat_length'] top hat legth should be larger than the largest feature to extract
+                       param['threshold'] should be larger than the residual image background
+        analyse_morpho (bool): if True do the morphological analysis 
+    Returns:
+        if analyse_morpho == True
+            df (dataframe): index|'x'|'long_x'| 'y'|'long_y'| 'size'|'depth' with :
+                - index: feature index
+                - x: gravity center x position of the feature
+                - long_x: maximum feature width
+                - y: gravity center y position of the feature
+                - long_y: maximum feature height
+                - size: pixels number of the feature 
+                - depth : feature depth 
+        if analyse_morpho == False  returns None
+    '''
 
     # 3rd party import
     from pathlib import Path
@@ -17,17 +83,18 @@ def image_processing_1(param, analyse_morpho=True):
     from .image_features_extract import fill_gap, analyse_morphologique
     from .image_features_extract import read_plu_topography, top_hat_flattening
 
-    # lecture de l'image
-    N, M, confocal_img, rgb = read_plu_topography(param["repertoire"] / param["file"])
-    confocal_img1 = fill_gap(confocal_img)
+    # .plu image reading and correction
+    N, M, confocal_img, rgb = read_plu_topography(param["repertoire"] / param["file"]) # fle .plu reading
+    confocal_img1 = fill_gap(confocal_img) # substitute non measured values by interpolated ones
 
-    # correction de l'image
-    im_corr = top_hat_flattening(-confocal_img1,param['Top_hat_length'] )
-    im_corr = -im_corr
     
+    # top hat processing
+    im_corr = top_hat_flattening(confocal_img1,param['Top_hat_length'],top_hat_sens=-1)
+    
+    # binarization
     im_bin = np.where(im_corr < param['threshold'], 1, 0)
 
-    # analyse morphologique
+    # morphological analysis
     df = None
     if analyse_morpho:
         file_save_excel = Path(param["file"]).stem + ".xlsx"
@@ -36,6 +103,9 @@ def image_processing_1(param, analyse_morpho=True):
     return confocal_img1, im_corr, im_bin, df
 
 def image_processing(param, analyse_morpho=True):
+    '''
+    depreciated use image_processing_1
+    '''
 
     # 3rd party import
     from pathlib import Path
@@ -80,6 +150,9 @@ def make_tex_document(
     flag=False,
     new_section=False,
 ):
+    '''
+    make_tex_document_1
+    '''
     # 3rd party import
     import numpy as np
     import matplotlib.pyplot as plt
@@ -191,7 +264,7 @@ def make_tex_document(
                     doc.write("\\hline\n")
             doc.write(r"\end{tabular} \end{center} ")
 
-            doc.write(r"\section{" + param["coupe"] + "}" + "\n")
+            doc.write(r"\section{" + param["cut"] + "}" + "\n")
         if new_section:
             doc.write(r"\subsection{" + param["wafer"] + "}" + "\n")
         doc.write(r"\subsubsection{" + param["file"] + "}" + "\n")
@@ -255,6 +328,18 @@ def make_tex_document(
 
 
 def build_bbox(param, size_min=50, method="ge"):
+    '''
+    aggregation of several box plot in a unique one.
+    
+    Arguments:
+        param (dict) : param["root"] root (Path)
+                       param["cut"] name of the cut directory
+        size_min (int) : threshold used to slect the features according to their size
+        method (string): if method = "ge" we build a bbox with features with size >= size_min
+                         if method = "lt" we build a bbox with features with size < size_min
+    Returns:
+        a PNG image stored in param["root"] / Path(param["cut"]) / Path("synthese" + method + str(size_min) + ".png"
+    '''
 
     import os
     
@@ -263,15 +348,16 @@ def build_bbox(param, size_min=50, method="ge"):
     from pathlib import Path
     import matplotlib.pyplot as plt
 
-    REP = [
-        param["root"] / Path(param["coupe"]) / Path("wafer " + str(i)) / Path("results")
-        for i in range(1, 6)
-    ]
+    import os
+    rep_wafers = [
+                  param["root"] / Path(param["cut"]) / Path(x) / Path("results") 
+                  for x in os.listdir(param["root"] / Path(param["cut"])) if  'wafer' in x
+                 ]
     s = {}
     len_max = 0
-    for rep in REP:
-        for x in [y for y in os.listdir(rep) if y.split(".")[-1] == "xlsx"]:
-            df = pd.read_excel(rep / x)
+    for rep_wafer in rep_wafers:
+        for x in [y for y in os.listdir(rep_wafer) if y.split(".")[-1] == "xlsx"]:
+            df = pd.read_excel(rep_wafer / x)
             key = x.split(".")[0]
             if method == "ge":
                 s[key] = df.query("size >= @size_min")["size"]
@@ -288,10 +374,10 @@ def build_bbox(param, size_min=50, method="ge"):
     df = pd.DataFrame.from_dict(s)
 
     ax = df.plot.box(rot=0, figsize=(8, 15), grid=True, vert=False)
-    ax.set_title(param['coupe'])
+    ax.set_title(param['cut'])
     plt.savefig(
         param["root"]
-        / Path(param["coupe"])
+        / Path(param["cut"])
         / Path("synthese" + method + str(size_min) + ".png"),
         bbox_inches="tight",
     )
@@ -323,17 +409,19 @@ def make_tex_document_1(
 
     fig = plt.figure(figsize=(8, 8))
     N, M, confocal_img, rgb = read_plu_topography(param['repertoire']/param['file'])
-
+    
+    # raw image save
     confocal_img1 = fill_gap(confocal_img)
     plt.imshow(confocal_img1, cmap='gray')
     plt.colorbar()
     mask = np.where(confocal_img == 1000001)
     plt.scatter(mask[1],mask[0],c='r',s =1,alpha=0.1 )
 
-    file_save_im_brute = Path(param["file"]).stem + "-im-brute.jpg"
-    plt.savefig(param["dir_results"] / file_save_im_brute, bbox_inches="tight")
+    file_save_im_raw = Path(param["file"]).stem + "-im-raw.jpg"
+    plt.savefig(param["dir_results"] / file_save_im_raw, bbox_inches="tight")
     plt.close(fig)
-
+    
+    # reconstructed image save
     fig = plt.figure(figsize=(8, 8))
     colorsMap = plt.get_cmap("plasma") #("RdYlGn")
     g = list(zip(np.array(df['x']),
@@ -346,7 +434,7 @@ def make_tex_document_1(
     cNorm = matplotlib.colors.Normalize(vmin=min(c), vmax=max(c))
     scalarMap = cmx.ScalarMappable(norm=cNorm, cmap=cm)
 
-    plt.scatter(np.array(y) ,N-np.array(x) ,s=np.array(s)/5, c=scalarMap.to_rgba(c))
+    plt.scatter(np.array(x) ,N-np.array(y) ,s=np.array(s)/5, c=scalarMap.to_rgba(c))
     plt.xlim(0,M)
     plt.ylim(0,N)
     scalarMap.set_array(c)
@@ -355,11 +443,11 @@ def make_tex_document_1(
                                    rotation=0)
     plt.colorbar(scalarMap)
 
-    
-    file_save_im_bin = Path(param["file"]).stem + "-im-bin.jpg"
-    plt.savefig(param["dir_results"] / file_save_im_bin, bbox_inches="tight")
+    file_save_im_rebuild = Path(param["file"]).stem + "-im-rebuild.jpg"
+    plt.savefig(param["dir_results"] / file_save_im_rebuild, bbox_inches="tight")
     plt.close(fig)
 
+    # features size histogram plot
     fig = plt.figure(figsize=(8, 8))
     ax1 = fig.add_subplot(111)
     ax1.hist(df["size"], bins=40)
@@ -367,6 +455,7 @@ def make_tex_document_1(
     plt.savefig(param["dir_results"] / file_save_im_hist, bbox_inches="tight")
     plt.close(fig)
 
+    # features size box plot
     fig = plt.figure(figsize=(8, 8))
     ax1 = fig.add_subplot(111)
     ax1.boxplot(df["size"])
@@ -374,8 +463,9 @@ def make_tex_document_1(
     plt.savefig(param["dir_results"] / file_save_im_erea, bbox_inches="tight")
     plt.close(fig)
 
+    # tex report generation
     file_save_doc_tex = Path(param["file"]).stem + "_doc_tex.tex"
-    with open(param["dir_tex"] / Path('rapport_'+param['coupe']+'.tex'), mode) as doc:
+    with open(param["dir_tex"] / Path('rapport_'+param['cut']+'.tex'), mode) as doc:
         if mode == "w":
             doc.write(
                 r"""\documentclass[a4paper, 10pt]{article}
@@ -419,7 +509,7 @@ def make_tex_document_1(
                     doc.write("\\hline\n")
             doc.write(r"\end{tabular} \end{center} ")
 
-            doc.write(r"\section{" + param["coupe"] + "}" + "\n")
+            doc.write(r"\section{" + param["cut"] + "}" + "\n")
         if new_section:
             doc.write(r"\subsection{" + param["wafer"] + "}" + "\n")
         doc.write(r"\subsubsection{" + param["file"] + "}" + "\n")
@@ -432,9 +522,9 @@ def make_tex_document_1(
         )
         doc.write(
             r"\includegraphics[width=0.5\textwidth]{"
-            + file_save_im_brute
+            + file_save_im_raw
             + r"} & \includegraphics[width=0.5\textwidth]{"
-            + file_save_im_bin
+            + file_save_im_rebuild
             + r"}\\"
             + "\n"
         )
